from setuptools import setup

setup(name='panorbit_add',
      version='0.1',
      description='basic math function',
      # url='http://github.com/storborg/funniest',
      author='panorbit',
      author_email='panorbit@example.com',
      license='MIT',
      packages=['panorbit_add'],
      install_requires=[
          'pyotp',
      ],
      zip_safe=False)
